@@ -1014,15 +1014,15 @@ testfile_path <- function(x, replace = FALSE) {
     out <- paste0(test_path, "/", x)
     url <- paste0("https://github.com/JanMarvin/openxlsx-data/raw/main/", x)
     try({
-      download.file(url, destfile = out, quiet = TRUE)
+      download.file(url, destfile = out, quiet = TRUE, mode = "wb")
     })
   }
 
   if (!file.exists(fl)) {
     return(testthat::skip("Testfile does not exist"))
-  } else {
-    return(fl)
   }
+
+  fl
 }
 
 
