@@ -23,10 +23,10 @@ test_that("wb_to_df", {
     class = "data.frame"
   )
   got <- wb_to_df(wb1)
-  expect_equal(exp, got, ignore_attr = TRUE)
+  expect_equal(got, exp, ignore_attr = TRUE)
 
   # do not convert first row to colNames
-  got <- wb_to_df(wb1, colNames = FALSE)
+  got <- wb_to_df(wb1, col_names = FALSE)
   expect_equal(int2col(seq_along(got)), names(got))
 
   # do not try to identify dates in the data
@@ -38,10 +38,10 @@ test_that("wb_to_df", {
 
   # return the underlying Excel formula instead of their values
   got <- wb_to_df(wb1, showFormula = TRUE)
-  expect_equal("1/0", got$Var7[1])
+  expect_equal(got$Var7[1], "1/0")
 
-  # read dimension withot colNames
-  got <- wb_to_df(wb1, dims = "A2:C5", colNames = FALSE)
+  # read dimension without colNames
+  got <- wb_to_df(wb1, dims = "A2:C5", col_names = FALSE)
   test <- data.frame(A = c(TRUE, TRUE, TRUE, FALSE),
                      B = c(1, NA, 2, 2),
                      C = rep(NA_real_, 4))
@@ -68,14 +68,14 @@ test_that("wb_to_df", {
 
   # # erase empty Rows from dataset
   # not gonna test this :) just want to mention how blazing fast it is now.
-  # got <- wb_to_df(wb1, sheet = 3, skipEmptyRows = TRUE)
+  # got <- wb_to_df(wb1, sheet = 3, skip_empty_rows = TRUE)
 
   # erase rmpty Cols from dataset
-  got <- wb_to_df(wb1, skipEmptyCols = TRUE)
+  got <- wb_to_df(wb1, skip_empty_cols = TRUE)
   expect_equal(exp[c(1, 2, 4, 5, 6, 7, 8)], got, ignore_attr = TRUE)
 
   # # convert first row to rownames
-  # wb_to_df(wb1, sheet = 3, dims = "C6:G9", rowNames = TRUE)
+  # wb_to_df(wb1, sheet = 3, dims = "C6:G9", row_names = TRUE)
 
   # define type of the data.frame
   got <- wb_to_df(wb1, cols = c(1, 4), types = c("Var1" = 0, "Var3" = 1))
@@ -89,11 +89,11 @@ test_that("wb_to_df", {
   test <- exp[4:10, ]
   names(test) <- int2col(seq_along(test))
   test[c("D", "G", "H")] <- lapply(test[c("D", "G", "H")], as.numeric)
-  expect_equal(test, got, ignore_attr = TRUE)
+  expect_equal(got, test, ignore_attr = TRUE)
 
   # na string
   got <- wb_to_df(wb1, na.strings = "")
-  expect_equal("#N/A", got$Var7[2], ignore_attr = TRUE)
+  expect_equal(got$Var7[2], "#N/A", ignore_attr = TRUE)
 
 
   ###########################################################################
@@ -113,7 +113,7 @@ test_that("wb_to_df", {
   rownames(exp) <- seq(2, nrow(exp) + 1)
   # read dataset with inlinestr
   got <- wb_to_df(wb2)
-  expect_equal(exp, got, ignore_attr = TRUE)
+  expect_equal(got, exp, ignore_attr = TRUE)
 
 
   ###########################################################################
@@ -122,14 +122,14 @@ test_that("wb_to_df", {
   expect_silent(wb3 <- wb_load(xlsxFile))
 
   # read dataset with named_region (returns global first)
+  got <- wb_to_df(wb3, named_region = "MyRange", col_names = FALSE)
   exp <- data.frame(A = "S2A1", B = "S2B1")
-  got <- wb_to_df(wb3, named_region = "MyRange", colNames = FALSE)
-  expect_equal(exp, got, ignore_attr = TRUE)
+  expect_equal(got, exp, ignore_attr = TRUE)
 
   # read named_region from sheet
+  got <- wb_to_df(wb3, named_region = "MyRange", sheet = 4, col_names = FALSE)
   exp <- data.frame(A = "S3A1", B = "S3B1")
-  got <- wb_to_df(wb3, named_region = "MyRange", sheet = 4, colNames = FALSE)
-  expect_equal(exp, got, ignore_attr = TRUE)
+  expect_equal(got, exp, ignore_attr = TRUE)
 
 })
 
@@ -145,7 +145,7 @@ test_that("select_active_sheet", {
     row.names = c(NA, 4L), class = "data.frame")
 
   # testing is the selected sheet
-  expect_identical(exp, wb_get_selected(wb))
+  expect_identical(wb_get_selected(wb), exp)
 
   # change the selected sheet to IrisSample
   exp <- structure(
@@ -155,14 +155,14 @@ test_that("select_active_sheet", {
      row.names = c(NA, 4L), class = "data.frame")
 
   wb <- wb_set_selected(wb, "IrisSample")
-  expect_identical(exp, wb_get_selected(wb))
+  expect_identical(wb_get_selected(wb), exp)
 
   # get the active sheet
-  expect_identical(2, wb_get_active_sheet(wb))
+  expect_identical(wb_get_active_sheet(wb), 2)
 
   # change the selected sheet to IrisSample
   wb <- wb_set_active_sheet(wb, sheet = "IrisSample")
-  expect_identical(1, wb_get_active_sheet(wb))
+  expect_identical(wb_get_active_sheet(wb), 1)
 
 })
 
@@ -190,7 +190,7 @@ test_that("dataframe_to_dims", {
 
   # dims_to_dataframe will always create a square
   df <- dims_to_dataframe("A1:D5;F1:F6;D8", fill = TRUE)
-  dims <- dataframe_to_dims(df)
+  dims <- dataframe_to_dims(df, dim_break = TRUE)
   df2 <- dims_to_dataframe(dims, fill = TRUE)
   expect_equal(df, df2)
 
@@ -218,10 +218,10 @@ test_that("handle 29Feb1900", {
     add_worksheet()$add_data(x = as_date)$
     add_worksheet()$add_data(x = as_posix)
 
-  got <- wb_to_df(wb, sheet = 1, colNames = FALSE)$A
+  got <- wb_to_df(wb, sheet = 1, col_names = FALSE)$A
   expect_equal(as_date, got)
 
-  got <- wb_to_df(wb, sheet = 2, colNames = FALSE)$A
+  got <- wb_to_df(wb, sheet = 2, col_names = FALSE)$A
   expect_equal(as_posix, got)
 
 })
@@ -229,12 +229,12 @@ test_that("handle 29Feb1900", {
 
 test_that("fillMergedCells works with dims", {
 
-  # create data frame with emtpy second row
+  # create data frame with empty second row
   wb <- wb_workbook()$
     add_worksheet()$
-    add_data(x = t(letters[1:4]), colNames = FALSE)$
+    add_data(x = t(letters[1:4]), col_names = FALSE)$
     add_data(1, t(matrix(c(1:3, NA_real_), 4, 4)),
-             startRow = 3, startCol = 1, colNames = FALSE)
+             start_row = 3, start_col = 1, col_names = FALSE)
 
   # merge rows 1 and 2 in each column
   wb$merge_cells(1, rows = 1:2, cols = 1)
@@ -243,11 +243,10 @@ test_that("fillMergedCells works with dims", {
   wb$merge_cells(1, rows = 1:2, cols = 4)
 
   # read from second column and fill merged cells
-  got <- wb_to_df(wb, dims = "A2:D4", fillMergedCells = TRUE)
+  got <- wb_to_df(wb, dims = "A2:D4", fill_merged_cells = TRUE)
 
   exp <- c("a", "b", "c", "d")
-  got <- names(got)
-  expect_equal(exp, got)
+  expect_equal(names(got), exp)
 
 })
 
@@ -255,9 +254,9 @@ test_that("improve date detection", {
 
   df <- wb_workbook() %>%
     wb_add_worksheet("Rawdata") %>%
-    wb_add_data(x = Sys.Date(), colNames = FALSE) %>%
+    wb_add_data(x = Sys.Date(), col_names = FALSE) %>%
     wb_add_numfmt(numfmt = "[$-1070000]d/mm/yyyy;@") %>%
-    wb_to_df(colNames = FALSE)
+    wb_to_df(col_names = FALSE)
 
   exp <- Sys.Date()
   got <- df$A
@@ -274,15 +273,14 @@ test_that("skip hidden columns and rows works", {
     set_row_heights(rows = c(3, 5, 8:30), hidden = TRUE)$
     add_data(dims = "M1", x = iris)
 
-  dat <- wb_to_df(wb, dims = "A1:K33", skipHiddenRows = TRUE, skipHiddenCols = TRUE)
+  dat <- wb_to_df(wb, dims = "A1:K33", skip_hidden_rows = TRUE, skip_hidden_cols = TRUE)
 
   exp <- c("2", "4", "6", "7", "31", "32", "33")
   got <- rownames(dat)
-  expect_equal(exp, got)
+  expect_equal(rownames(dat), exp)
 
   exp <- c("cyl", "disp", "drat", "vs", "gear", "carb")
-  got <- names(dat)
-  expect_equal(exp, got)
+  expect_equal(names(dat), exp)
 
 })
 
@@ -315,3 +313,109 @@ test_that("missings cells are returned", {
   expect_silent(got <- wb_to_df(wb, col_names = FALSE, rows = c(101), cols = c(27)))
 
 })
+
+test_that("dims with separator work", {
+
+  wb <- wb_workbook()$
+    # this picks the top left corner of dims to write the data frame
+    add_worksheet()$add_data(dims = "I2:J2;A1:B2;G5:H6", x = matrix(1:8, 4, 2))$
+    add_worksheet()$add_data(dims = "I2:J2;A1:B2;G5:H6", x = matrix(1:8, 4, 2), enforce = TRUE)
+
+  exp <- c("A1", "B1", "A2", "B2", "A3", "B3", "A4", "B4", "A5", "B5")
+  got <- wb$worksheets[[1]]$sheet_data$cc$r
+  expect_equal(exp, got)
+
+  exp <- c("I2", "J2", "A1", "B1", "A2", "B2", "G5", "H5", "G6", "H6")
+  got <- wb$worksheets[[2]]$sheet_data$cc$r
+  expect_equal(exp, got)
+
+  # write a workbook with a few colored cells
+  wb <- wb_workbook()$
+    add_worksheet()$
+    add_data(dims = wb_dims(x = mtcars), x = mtcars, enforce = TRUE)$
+    add_worksheet()$
+    add_data(dims = "A1:K20,A22:K34", x = mtcars, enforce = TRUE)$
+    add_worksheet()$
+    add_data(dims = "I2:J2;A1:B2;G5:H6", x = matrix(1:8, 4, 2), enforce = TRUE)
+
+  # sheet 1
+  df <- wb_to_df(wb, sheet = 1)
+  expect_equal(df, mtcars, ignore_attr = TRUE)
+
+  # sheet 2
+  df <- wb_to_df(wb, sheet = 2)
+  expect_true(all(is.na(df[20, ])))
+  expect_equal(df[-20, ], mtcars, ignore_attr = TRUE)
+
+  # sheet 3
+  df <- wb_to_df(wb, sheet = 3, col_names = FALSE)
+  ll <- list(
+    df["2", c("I", "J")],
+    df[c("1", "2"), c("A", "B")],
+    df[c("5", "6"), c("G", "H")]
+  )
+
+  for (i in seq_len(length(ll)))
+    names(ll[[i]]) <- c("V1", "V2")
+
+  exp <- data.frame(
+    V1 = c("V1", 1, 2, 3, 4),
+    V2 = c("V2", 5, 6, 7, 8)
+  )
+
+  got <- do.call("rbind", ll)
+  expect_equal(exp, got, ignore_attr = TRUE)
+
+  wb$add_worksheet()$add_formula(dims = "D1;F2", x = c("SUM(A1:C1)", "SUM(A1)"), enforce = TRUE)
+  exp <- c("D1", "F2")
+  got <- wb$worksheets[[4]]$sheet_data$cc$r
+  expect_equal(exp, got)
+
+  # write to different dims
+  dat <- as.data.frame(matrix(1:15, ncol = 3))
+
+  wb <- wb_workbook()
+
+  # write columns separately
+  wb$add_worksheet()$
+    add_data(dims = "A1:A6", x = dat[, 1, drop = FALSE],
+            enforce = TRUE, col_names = TRUE)$
+    add_data(dims = "C2:C4,C6:C7", x = dat[, 2, drop = FALSE],
+            enforce = TRUE, col_names = FALSE)
+
+  # write columns as unique cells
+  wb$add_worksheet()$
+    add_data(dims = "A1,B2,C3,D4,E5,F6,C1,D2,E3,F4,G5,H6,I1:I6", x = dat,
+            enforce = TRUE, col_names = TRUE)
+
+  # write columns as two column ranges
+  wb$add_worksheet()$
+    add_data(dims = "A1:A6,C1:C6,E1:E6", x = dat,
+            enforce = TRUE, col_names = TRUE)
+
+  # write columns as two row ranges
+  wb$add_worksheet()$
+    add_data(dims = "A1:C3,B5:D7", x = dat,
+            enforce = TRUE, col_names = TRUE)
+
+
+  exp <- c("A1", "A2", "C2", "A3", "C3", "A4", "C4", "A5", "C5", "A6", "C6", "C7")
+  got <- wb$worksheets[[1]]$sheet_data$cc$r
+  expect_equal(exp, got)
+
+  exp <- c("A1", "C1", "I1", "B2", "D2", "I2", "C3", "E3", "I3", "D4",
+          "F4", "I4", "E5", "G5", "I5", "F6", "H6", "I6")
+  got <- wb$worksheets[[2]]$sheet_data$cc$r
+  expect_equal(exp, got)
+
+  exp <- c("A1", "C1", "E1", "A2", "C2", "E2", "A3", "C3", "E3", "A4",
+          "C4", "E4", "A5", "C5", "E5", "A6", "C6", "E6")
+  got <- wb$worksheets[[3]]$sheet_data$cc$r
+  expect_equal(exp, got)
+
+  exp <- c("A1", "B1", "C1", "A2", "B2", "C2", "A3", "B3", "C3", "B5",
+          "C5", "D5", "B6", "C6", "D6", "B7", "C7", "D7")
+  got <- wb$worksheets[[4]]$sheet_data$cc$r
+  expect_equal(exp, got)
+
+})
